Struct State
pub struct State { /* private fields */ }Available on crate feature
advanced only.Expand description
The internal state of an Editor.
Implementations
impl State
impl State
pub fn update<Message>(
&mut self,
editor: &impl Editor,
event: &Event,
bounds: Rectangle,
padding: Padding,
cursor: Cursor,
key_binding: impl Fn(KeyPress) -> Option<Binding<Message>>,
) -> Option<Update<Message>>
pub fn update<Message>( &mut self, editor: &impl Editor, event: &Event, bounds: Rectangle, padding: Padding, cursor: Cursor, key_binding: impl Fn(KeyPress) -> Option<Binding<Message>>, ) -> Option<Update<Message>>
pub fn input_method<'a>(
&'a self,
editor: &impl Editor,
position: Point,
) -> InputMethod<&'a str>
pub fn input_method<'a>( &'a self, editor: &impl Editor, position: Point, ) -> InputMethod<&'a str>
Returns the current InputMethod of the State for the given Editor.
pub fn draw<Renderer>(
&self,
editor: &<Renderer as Renderer>::Editor,
renderer: &mut Renderer,
position: Point,
clip_bounds: Rectangle,
style: Style,
)where
Renderer: Renderer,
pub fn draw<Renderer>(
&self,
editor: &<Renderer as Renderer>::Editor,
renderer: &mut Renderer,
position: Point,
clip_bounds: Rectangle,
style: Style,
)where
Renderer: Renderer,
pub fn is_cursor_visible(&self) -> bool
pub fn is_cursor_visible(&self) -> bool
Returns whether the cursor of the Editor is visible.
impl State
impl State
pub fn is_focused(&self) -> bool
pub fn is_focused(&self) -> bool
Returns whether the Editor is currently focused or not.